@@ -31,7 +31,7 @@ from itertools import product
 from functools import reduce
 from datetime import datetime
 import platform as __platform
-if 'arm' not in __platform.uname()[4]:
+if 'arm' not in __platform.machine():
     import git
 import re
 from pathlib import Path
